NsgDataEnumReferenceField<T extends NsgEnum> class

Inheritance

Constructors

NsgDataEnumReferenceField(String name)

Properties

defaultValue → dynamic
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
presentation ↔ String
getter/setter pairinherited
referentElementType → Type
no setterinherited
referentType → Type
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(NsgDataItem a, NsgDataItem b) → int
override
convertJsonValue(dynamic jsonValue) → dynamic
override
convertToJson(dynamic jsonValue) → dynamic
inherited
formattedValue(NsgDataItem item, String locale) → String
inherited
getReferent(NsgDataItem dataItem, {bool useCache = true}) → T?
getReferentAsync(NsgDataItem dataItem, {bool useCache = true}) → Future<NsgDataItem>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEmpty(NsgFieldValues fieldValues) → void
inherited
setValue(NsgFieldValues fieldValues, dynamic value) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited