NsgCompare class

Constructors

NsgCompare()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Проверка наличия в фильтре хотя бы одного условия
no setter
isNotEmpty → bool
no setter
length → int
no setter
lengthAll → int
Возвращаем количество параметров с учетов всех вложенных параметров
no setter
logicalOperator ↔ NsgLogicalOperator
логический оператор
getter/setter pair
paramList ↔ List<NsgCompareParam>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add({required String name, required dynamic value, NsgComparisonOperator comparisonOperator = NsgComparisonOperator.equal}) → void
clear() → void
isValid(NsgDataItem item) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited