NsgCompareParam class

Constructors

NsgCompareParam({required String parameterName, required dynamic parameterValue, NsgComparisonOperator comparisonOperator = NsgComparisonOperator.equal})

Properties

comparisonOperator → NsgComparisonOperator
Оператор сравнения
final
hashCode → int
The hash code for this object.
no setterinherited
parameterName → String
Значение
final
parameterValue → dynamic
Значение
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

convertToJson(dynamic parameterValue) → dynamic
isValid(NsgDataItem item) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited