NsgItemList class

Constructors

NsgItemList()

Properties

hashCode int
The hash code for this object.
no setterinherited
items Map<String, NsgDataCashedItem>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add({required NsgDataItem item, DateTime? time, String? tag = ''}) → void
getItem(String id) NsgDataCashedItem?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited